#include "tdmp/networking.lua"
#include "tdmp/player.lua"

#include "library.lua"
#include "setup.lua"
#include "PauseOptions.lua"

function init()
    -- inits find shapes and bodies--
    DoorsInit = FindBodies("ALSdoor", true)
    SoundShape = FindShapes("ALShorn", true)
    Noclip = FindShapes("noclip", true)
    frame = 0
    SetBool("level.ALS.enabled", true)
    SetFloat("lightsf", GetFloat(pathUi.."lightsf"))
    SetFloat("lightst", GetFloat(pathUi.."lightst"))
    SetFloat("HighBeam", GetFloat(pathUi.."HighBeam"))
    SetFloat("EmLights", GetFloat(pathUi.."EmLights"))
    SetString("emergency.menu", GetString(pathKey.."menu"))
    SetString("emergency.primary", GetString(pathKey.."primary"))
    SetString("emergency.secondary", GetString(pathKey.."secondary"))
    SetString("emergency.tertiary", GetString(pathKey.."tertiary"))
    SetString("emergency.directional", GetString(pathKey.."directional"))




    -- keys binds and options--
    initOptions()
    Setup(DontUpdate)
    ReloadKeys()

    -- sonds inits--
    chimeList = {}
    chimeList[#chimeList + 1] = LoadLoop("sound/chime01.ogg")
    chimeList[#chimeList + 1] = LoadLoop("sound/chime02.ogg")

    clickList = {}
    clickList[#clickList + 1] = LoadSound("sound/beepon.ogg")
    clickList[#clickList + 1] = LoadSound("sound/beepoff.ogg")
    clickList[#clickList + 1] = LoadSound("sound/click.ogg")

    doorList = {}
    doorList[#doorList + 1] = LoadLoop("sound/caropen.ogg")
    doorList[#doorList + 1] = LoadLoop("sound/carclose.ogg")

    honkList = {}
    honkList[#honkList + 1] = LoadLoop("sound/honk01.ogg")
    honkList[#honkList + 1] = LoadLoop("sound/honk02.ogg")
    honkList[#honkList + 1] = LoadLoop("sound/honk03.ogg")
    honkList[#honkList + 1] = LoadLoop("sound/honk04.ogg")

    sirenPrimary = {}
    sirenPrimary[#sirenPrimary + 1] = LoadLoop("sound/sirenP01.ogg")
    sirenPrimary[#sirenPrimary + 1] = LoadLoop("sound/sirenP02.ogg")
    sirenPrimary[#sirenPrimary + 1] = LoadLoop("sound/sirenP03.ogg")
    sirenPrimary[#sirenPrimary + 1] = LoadLoop("sound/sirenP04.ogg")

    sirenSecondary = {}
    sirenSecondary[#sirenSecondary + 1] = LoadLoop("sound/sirenS01.ogg")
    sirenSecondary[#sirenSecondary + 1] = LoadLoop("sound/sirenS02.ogg")
    sirenSecondary[#sirenSecondary + 1] = LoadLoop("sound/sirenS03.ogg")
    sirenSecondary[#sirenSecondary + 1] = LoadLoop("sound/sirenS04.ogg")

    sirenTertiary = {}
    sirenTertiary[#sirenTertiary + 1] = LoadLoop("sound/sirenT01.ogg")
    sirenTertiary[#sirenTertiary + 1] = LoadLoop("sound/sirenT02.ogg")

    sirenFourth = {}
    sirenFourth[#sirenFourth + 1] = LoadLoop("sound/sirenQ01.ogg")

    local showLargeUI = GetBool("game.largeui")
    if showLargeUI then
		gUiScaleUpFactor = 1.3
    else 
        gUiScaleUpFactor = 1.0
	end

    if TDMP_LocalSteamId then

        TDMP_RegisterEvent("ALS_Directional", function(data, sender)
            local steamId = sender or data
            
            local veh = Player(steamId):GetVehicle()
            ALS_Directional(veh, HasTag(veh, "di"))

            if not TDMP_IsServer() then return end

            TDMP_ServerStartEvent("ALS_Directional", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
        
                DontPack = true,
                Data = sender
            })
        end)

        TDMP_RegisterEvent("ALS_CHangeEMS", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[3]

            local veh = Player(steamId):GetVehicle()
            ALS_CHangeEMS(veh, "emergency", GetTagValue(veh, data[2]) == data[1], data[2], data[1])

            if not TDMP_IsServer() then return end
            data[3] = steamId
    
            TDMP_ServerStartEvent("ALS_CHangeEMS", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_CHangeLights", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[3]

            local veh = Player(steamId):GetVehicle()
            ALS_CHangeLights(veh, data[2], clickList, HasTag(veh, data[1]), data[1])

            if not TDMP_IsServer() then return end
            data[3] = steamId
    
            TDMP_ServerStartEvent("ALS_CHangeLights", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_CHangeMultipleLights", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[3]

            local veh = Player(steamId):GetVehicle()
            ALS_CHangeMultipleLights(veh, clickList, GetTagValue(veh, data[2]) == data[1], data[2], data[1])

            if not TDMP_IsServer() then return end
            data[3] = steamId
    
            TDMP_ServerStartEvent("ALS_CHangeMultipleLights", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_SendPatter", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[3]

            local veh = Player(steamId):GetVehicle()
            SetTag(veh, data[1], data[2])
            SetTag(veh, "update")
            if not TDMP_IsServer() then return end
            data[3] = steamId
    
            TDMP_ServerStartEvent("ALS_SendPatter", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_SendPatterDirectional", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[2]

            local veh = Player(steamId):GetVehicle()
            SetTag(veh, "directional",  data[1])
            
            if not TDMP_IsServer() then return end
            data[2] = steamId
    
            TDMP_ServerStartEvent("ALS_SendPatterDirectional", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_lat_ON", function(data, sender)
            local steamId = sender or data
            
            local veh = Player(steamId):GetVehicle()
            if HasTag(veh, "ALS") then
                SetTag(veh, "lat")
            end

            if not TDMP_IsServer() then return end

            TDMP_ServerStartEvent("ALS_lat_ON", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
        
                DontPack = true,
                Data = sender
            })
        end)

        TDMP_RegisterEvent("ALS_lat_OFF", function(data, sender)
            local steamId = sender or data
            
            local veh = Player(steamId):GetVehicle()
            if HasTag(veh, "ALS") then
                RemoveTag(veh, "lat")
            end

            if not TDMP_IsServer() then return end

            TDMP_ServerStartEvent("ALS_lat_OFF", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
        
                DontPack = true,
                Data = sender
            })
        end)


        TDMP_RegisterEvent("ALS_Emergency_Sound", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[2]

            for i=1, #SoundShape do
                if Player(steamId):GetVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                    ALS_ChangeSound(SoundShape[i], GetTagValue(SoundShape[i], "ALSsiren") == data[1], "ALSsiren", data[1])
                end
            end
            
            if not TDMP_IsServer() then return end
            data[2] = steamId
    
            TDMP_ServerStartEvent("ALS_Emergency_Sound", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        TDMP_RegisterEvent("ALS_Temp_ON", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[2]

            for i=1, #SoundShape do
                if Player(steamId):GetVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                    SetTag(SoundShape[i], data[1])
                end
            end
            
            if not TDMP_IsServer() then return end
            data[2] = steamId
    
            TDMP_ServerStartEvent("ALS_Temp_ON", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

        
        TDMP_RegisterEvent("ALS_Temp_OFF", function(jsonData, steamId)
            local data = json.decode(jsonData)
            steamId = steamId or data[2]

            for i=1, #SoundShape do
                if Player(steamId):GetVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                    RemoveTag(SoundShape[i], data[1])
                end
            end
            
            if not TDMP_IsServer() then return end
            data[2] = steamId
    
            TDMP_ServerStartEvent("ALS_Temp_OFF", {
                Receiver = TDMP.Enums.Receiver.ClientsOnly,
                Reliable = true,
    
                DontPack = false,
                Data = data
            })
        end)

    end
end

function update(dt)
    local veh = GetPlayerVehicle()
    if showpanel then
        if HasTag(veh, "em") or HasTag(veh, "di") then
            frame = frame + dt*60
            local period = 120
            local t = math.ceil(frame) % period
            
            patterimage(t)
            if frame > 120 then
                frame = 0
            end
        end
    end
end

function tick(dt)
    local veh = GetPlayerVehicle()
    
    Noclip = FindShapes("noclip", true)
    for i=1, #Noclip do
        SetShapeCollisionFilter(Noclip[i], 2, 255-2)
    end



    --find shapes where the siren will play
    SoundShape = FindShapes("ALShorn", true)
    --find doors
    DoorsInit = FindBodies("ALSdoor", true)


    -- =========--
    --  doors  --
    -- =========--

    --Fix to call only one time every click on the door
    --Fix to suport TDMP
    if GetBool(pathUi .. "ClickDoor") then
        DoorClick("open", "close", DoorsInit)
    end
    if GetBool(pathUi .. "HoldDoor") then 
        DoorHold(DoorsInit) 
    end
    if GetBool(pathUi .. "OpenWhenExit") then
        DoorExit("open", "close", DoorsInit)
    end


    --//binds enable only when on vihicle//--
    if HasTag(veh, "ALS") then

    --//binds enable only when on emergency vihicle//--
    if HasTag(veh, "emergency") then
    --=========--
    --  Sonds  --
    --=========--
    --//sirens//--
        if InputPressed(honksCtrl[1]) then
            if TDMP_LocalSteamId then
                local p = "1"
                TDMP_ClientStartEvent("ALS_Emergency_Sound", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        ALS_ChangeSound(SoundShape[i], GetTagValue(SoundShape[i], "ALSsiren") == "1", "ALSsiren", "1")
                    end
                end
            end
        elseif InputPressed(honksCtrl[2]) then
            if TDMP_LocalSteamId then
                local p = "2"
                TDMP_ClientStartEvent("ALS_Emergency_Sound", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        ALS_ChangeSound(SoundShape[i], GetTagValue(SoundShape[i], "ALSsiren") == "2", "ALSsiren", "2")
                    end
                end
            end
        elseif InputPressed(honksCtrl[3]) then
            if TDMP_LocalSteamId then
                local p = "3"
                TDMP_ClientStartEvent("ALS_Emergency_Sound", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        ALS_ChangeSound(SoundShape[i], GetTagValue(SoundShape[i], "ALSsiren") == "3", "ALSsiren", "3")
                    end
                end
            end
        elseif InputPressed(honksCtrl[7]) then
            if TDMP_LocalSteamId then
                local p = "4"
                TDMP_ClientStartEvent("ALS_Emergency_Sound", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        ALS_ChangeSound(SoundShape[i], GetTagValue(SoundShape[i], "ALSsiren") == "4", "ALSsiren", "4")
                    end
                end
            end
        end

        --//temp//--
        if InputPressed(honksCtrl[5]) then
            if TDMP_LocalSteamId then
                local p = "Yell"
                TDMP_ClientStartEvent("ALS_Temp_ON", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        SetTag(SoundShape[i], "Yell")
                        --DebugPrint("Yell")
                    end
                end
            end
        elseif InputReleased(honksCtrl[5]) then
            if TDMP_LocalSteamId then
                local p = "Yell"
                TDMP_ClientStartEvent("ALS_Temp_OFF", { Reliable = true, Data = {p} })
            else
            for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        RemoveTag(SoundShape[i], "Yell")
                        --DebugPrint("deleted")
                    end
                end
            end
        end

        --//temp2//--
        if InputPressed(honksCtrl[6]) then
            if TDMP_LocalSteamId then
                local p = "Yell2"
                TDMP_ClientStartEvent("ALS_Temp_ON", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        SetTag(SoundShape[i], "Yell2")
                        --DebugPrint("Yell2")
                    end
                end
            end
        elseif InputReleased(honksCtrl[6]) then
            if TDMP_LocalSteamId then
                local p = "Yell2"
                TDMP_ClientStartEvent("ALS_Temp_OFF", { Reliable = true, Data = {p} })
            else
                for i=1, #SoundShape do
                    if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                        RemoveTag(SoundShape[i], "Yell2")
                        --DebugPrint("deleted")
                    end
                end
            end
        end


        --=========--
        --  Binds  --
        --=========--

        --//emergency lights (I,O,P)//--
        if InputPressed(lightKeys[9]) then
            if TDMP_LocalSteamId then
                local p = "1" local d = "em"
                TDMP_ClientStartEvent("ALS_CHangeEMS", { Reliable = true, Data = {p, d} })
                if GetTagValue(veh, "em") == "1" then
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5) 
                end
            else
                ALS_CHangeEMS(veh, "emergency", GetTagValue(veh, "em") == "1", "em", "1")
                if GetTagValue(veh, "em") == "1" then
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5) 
                end
            end
        elseif InputPressed(lightKeys[10]) then
            if TDMP_LocalSteamId then
                local p = "2" local d = "em"
                TDMP_ClientStartEvent("ALS_CHangeEMS", { Reliable = true, Data = {p, d} })
                if GetTagValue(veh, "em") == "2" then
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5) 
                end
            else
                ALS_CHangeEMS(veh, "emergency", GetTagValue(veh, "em") == "2", "em", "2")
                if GetTagValue(veh, "em") == "2" then
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5) 
                end
            end
        elseif InputPressed(lightKeys[11]) then
            if TDMP_LocalSteamId then
                local p = "3" local d = "em"
                TDMP_ClientStartEvent("ALS_CHangeEMS", { Reliable = true, Data = {p, d} })
                if GetTagValue(veh, "em") == "3" then
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5) 
                end
            else
                ALS_CHangeEMS(veh, "emergency", GetTagValue(veh, "em") == "3", "em", "3")
                if GetTagValue(veh, "em") == "3" then
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5) 
                end
            end
        end

        --//Directional lights (U)//--
        if InputPressed(lightKeys[12]) then
            if TDMP_LocalSteamId then
                TDMP_ClientStartEvent("ALS_Directional", { Reliable = true,DontPack = true, Data = "" })
                if HasTag(veh, "di") then
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5) 
                end
            else
                ALS_Directional(veh, HasTag(veh, "di"))
                if HasTag(veh, "di") then
                    PlaySound(clickList[01],GetCameraTransform().pos,0.5)
                else
                    PlaySound(clickList[02],GetCameraTransform().pos,0.5) 
                end
            end
        end
    end

    --=========--
    --  sound  --
    --=========--
    
    --//horn//--
    if InputPressed(honksCtrl[4]) then
        if TDMP_LocalSteamId then
            local p = "Horn"
            TDMP_ClientStartEvent("ALS_Temp_ON", { Reliable = true, Data = {p} })
        else
            for i=1, #SoundShape do
                if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                    SetTag(SoundShape[i], "Horn")
                    --DebugPrint("Horn")
                end
            end
        end
    elseif InputReleased(honksCtrl[4]) then
        if TDMP_LocalSteamId then
            local p = "Horn"
            TDMP_ClientStartEvent("ALS_Temp_OFF", { Reliable = true, Data = {p} })
        else
            for i=1, #SoundShape do
                if GetPlayerVehicle() == GetBodyVehicle(GetShapeBody(SoundShape[i])) then
                    RemoveTag(SoundShape[i], "Horn")
                    --DebugPrint("deleded")
                end
            end
        end
    end

    --=========--
    --  Binds  --
    --=========--
    
    if HasTag(veh, "aditional") then
    --//Aditional lights (N)//--
        if InputPressed(lightKeys[6]) then
            if TDMP_LocalSteamId then
                local p = "ad" local d = "aditional"
                TDMP_ClientStartEvent("ALS_CHangeLights", { Reliable = true, Data = {p, d} })
            else
                ALS_CHangeLights(veh, "aditional", clickList, HasTag(veh, "ad"), "ad")
            end

                PlaySound(clickList[03],GetCameraTransform().pos,0.8)
        end
    end

    --//Normal Beam (J)//--
    if InputPressed(lightKeys[1]) then
        if TDMP_LocalSteamId then
            local p = "l" local d = "ALS"
            TDMP_ClientStartEvent("ALS_CHangeLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeLights(veh, "ALS", clickList, HasTag(veh, "l"), "l")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    end

    --//Normal Beam (K)//--
    if InputPressed(lightKeys[2]) then
        if TDMP_LocalSteamId then
            local p = "la" local d = "ALS"
            TDMP_ClientStartEvent("ALS_CHangeLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeLights(veh, "ALS", clickList, HasTag(veh, "la"), "la")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    end

    --//Fog light (H)//--
    if InputPressed(lightKeys[4]) then
        if TDMP_LocalSteamId then
            local p = "fa" local d = "ALS"
            TDMP_ClientStartEvent("ALS_CHangeLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeLights(veh, "ALS", clickList, HasTag(veh, "fa"), "fa")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    end

    --//Blinkers (M,<,>)//--
    if InputPressed(lightKeys[5]) then
        if TDMP_LocalSteamId then
            local p = "3" local d = "p"
            TDMP_ClientStartEvent("ALS_CHangeMultipleLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeMultipleLights(veh, clickList, GetTagValue(veh, "p") == "3", "p", "3")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    elseif InputPressed(lightKeys[7]) then
        if TDMP_LocalSteamId then
            local p = "2" local d = "p"
            TDMP_ClientStartEvent("ALS_CHangeMultipleLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeMultipleLights(veh, clickList, GetTagValue(veh, "p") == "2", "p", "2")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    elseif InputPressed(lightKeys[8]) then
        if TDMP_LocalSteamId then
            local p = "1" local d = "p"
            TDMP_ClientStartEvent("ALS_CHangeMultipleLights", { Reliable = true, Data = {p, d} })
        else
            ALS_CHangeMultipleLights(veh, clickList, GetTagValue(veh, "p") == "1", "p", "1")
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    end

    --//High Beam (L)//--
    if InputPressed(lightKeys[3]) then
        if TDMP_LocalSteamId then
            TDMP_ClientStartEvent("ALS_lat_ON", { Reliable = true,DontPack = true, Data = "" })
        else
            if HasTag(veh, "ALS") then
                SetTag(veh, "lat")
                --DebugPrint("lat")
            end
        end
        PlaySound(clickList[03],GetCameraTransform().pos,0.8)
    elseif InputReleased(lightKeys[3]) then
        if TDMP_LocalSteamId then
            TDMP_ClientStartEvent("ALS_lat_OFF", { Reliable = true,DontPack = true, Data = "" })
        else
            if HasTag(veh, "ALS") then
                RemoveTag(veh, "lat")
                --DebugPrint("deleted")
            end
        end
    end
end


    --//play audio//--
    ALS_PlaySound(SoundShape, sirenPrimary, sirenSecondary, sirenTertiary, sirenFourth, honkList)



    if PauseMenuButton("ALS Options") then
		visible = true
	end
    if InputReleased(uiKeys[1]) then
        if  HasTag(veh, "emergency") then
        showpanel = not showpanel
        end
    end
    if not HasTag(veh, "emergency") then
        showpanel = false
    end

end






function draw()
    --vehicle bind hud
    if GetBool("game.vehicle.interactive") then
        drawVehicle(gUiScaleUpFactor, lightKeys, honksCtrl, uiKeys)
    end

    if GetBool("savegame.mod.Update.update") then
        UiPush()
        UiMakeInteractive()
        SetBool("game.disablepause", true)
		SetBool("game.disablemap", true)
        local w = UiWidth()
        local h = UiHeight()
        UiTranslate(w/2, h/2.2)
        UiAlign("center middle")
        UiColor(0, 0, 0, 0.8)
        UiImageBox("MOD/images/box-solid-6.png",800,400,10,10)

        UiPush()
        UiColor(0.5, 0.2, 0.2, 0.8)
        UiTranslate(0, -250)
        UiImageBox("MOD/images/box-solid-6.png",800,70,10,10)
        UiPop()
        
        UiPush()
        UiColor(1, 1, 1)
            UiPush()
                UiAlign("center middle")
                UiFont("bold.ttf", 50)
                UiTranslate(0, -250)
                UiText("UPDATE: 0.1")
            UiPop()
            UiPush()
            UiTranslate(-350, -250)
            UiImage("MOD/images/logodarksmall.png")
            UiPop()

        
        UiAlign("left bottom")
        UiTranslate(-380, -140)
        UiFont("regular.ttf", 25)
        UiText("- TDMP Support")
        UiTranslate(0, 40)
        UiText("- Changed some default binds to make it compatible with TDMP")
        UiTranslate(0, 40)
        UiText("- Changed the default brightness of the lights")
        UiTranslate(0, 40)
        UiText("- Added: POP UP headlight")
        UiTranslate(0, 40)
        UiText("- Added: way to initialize the vehicle with different patterns (for modders)")
        UiTranslate(0, 40)
        UiText("- Removed: Option to delete vehicle when destroyed")
        UiTranslate(0, 40)
        UiText("- Fixed: 'ALS MISSING' message when vehicle gets deleted by performance mods")
        UiTranslate(0, 40)
        UiText("- NOTE: The performance mod will keep deleting the vehicles")
        UiPop()


        UiTranslate(0, 300)
        UiColor(1, 1, 1)
        UiButtonImageBox("MOD/images/box-buttons.png", 6, 6, 1, 0.3, 0.3, 0.9)
    
        UiColor(1, 1, 1)
        UiFont("bold.ttf", 40)
        close = UiTextButton("CLOSE", 600, 60)
    
        if close or InputPressed("esc") then SetBool("savegame.mod.Update.update", false) end
        UiPop()
    end


    if showpanel then
        SetBool("game.disablepause", true)
		SetBool("game.disablemap", true)	
        drawOptionsF3(veh)
    end
    
    if visible then
        if not InputDown("rmb") then
            UiMakeInteractive()
            UiPush()
            UiAlign("left top")
            UiTranslate(1100, 70)
            UiColor(1, 1, 1)
            UiFont("regular.ttf", 40)
            UiText("Right click to move the camera")
            UiPop()
        end
        --disable the pause and map
        SetBool("game.disablepause", true)
		SetBool("game.disablemap", true)	

        --print the options
        drawOptions()
    end
end

